Learn R Programming

rNeighborGWAS (version 1.2.4)

delta_PVE: Estimating the effective scale of neighbor effects

Description

A function to calculate \(\Delta\)PVE that estimates the effective scale of neighbor effects.

Usage

delta_PVE(res, fig = TRUE, ...)

Value

Estimated effective scale and proportion of phenotypic variation explained by neighbor effects at that scale.

Arguments

res

Output results of calc_PVEnei().

fig

TRUE/FALSE to plot the results (or not). Default is TRUE.

...

Arguments to be passed to plot().

Author

Yasuhiro Sato (sato.yasuhiro.36c@kyoto-u.jp)

See Also

calc_PVEnei