gaston2neiGWAS: Convert gaston's bed.matrix data to rNeighborGWAS genotype data.
Description
A function convert a bed.matrix dataset to rNeighborGWAS genotype data.
Usage
gaston2neiGWAS(x)
Value
A list including an individual x marker matrix, a data.frame including chromosome numbers in the first column, and SNP positions in the second column, and a numeric vector including phenotypes for individuals.
geno Individual x marker matrix
gmap Data.frame including chromosome numbers in the first column, and SNP positions in the second column
pheno Numeric vector including phenotypes for individuals
Arguments
x
A bed.matrix created using the gaston package (Perdry & Dandine-Roulland 2020).