A function to provide coefficients and p-values of self and neighbor effects for each marker.
nei_lm(
geno,
g_nei,
pheno,
addcovar = NULL,
response = c("quantitative", "binary"),
n_core = 1L,
asym = FALSE
)A data.frame including coefficients and p-values of self and neighbor effects, without the chromosome numbers and marker position.
beta_self coefficient for self effects
beta_self coefficient for neighbor effects
p_self p-value for self effects by a likelihood ratio test between a null and standard linear model
p_nei p-value for neighbor effects by a likelihood ratio test between models with or without neighbor effects
An individual x marker matrix. Bialleles (i.e., A or a) must be converted into -1 or 1 digit.
An output of nei_coval() object, namely an individual x marker matrix including neighbor genotypic identity.
A numeric vector including phenotypes for individuals
An optional matrix including additional non-genetic covariates. It contains no. of individuals x no. of covariates.
An option to select if the phenotype is a "quantitative" trait subject to linear models, or a "binary" trait subject to logistic models.
No. of cores for a multi-core computation. This does not work for Windows OS. Default is a single-core computation.
If TRUE, asymmetric neighbor effects are also tested and returned as "beta_sxn" and "p_sxn".
Yasuhiro Sato (sato.yasuhiro.36c@kyoto-u.jp)
This function is a subset of neiGWAS(). nei_lm() gives detailed results when the option model="lm" is selected in neiGWAS().
neiGWAS