Learn R Programming

rNeighborGWAS (version 1.2.4)

qtl_pheno_simu: Simulating phenotype values with neighbor effects.

Description

A function to simulate phenotype values with multiple sources of variation controlled

Usage

qtl_pheno_simu(
  b_self,
  b_nei,
  eigenK_self,
  eigenK_nei,
  b_ratio = c(1, 1),
  pveB,
  pve
)

Value

A list of simulated phenotypes

  • y Simulated phenotype values

  • beta_self major self-genetic effects

  • beta_nei major neighbor effects

  • sigma_self self polygenic effects

  • sigma_nei neighbor polygenic effects

  • epsilon residuals

  • res_pveB realized proportion of variation explained by major-effect genes

  • res_pve realized proportion of variation explained by major-effect genes and polygenic effects

Arguments

b_self

A n x 1 genotype vector to design major additive genetic effect.

b_nei

A vector of an explanatory variable for neighbor effects

eigenK_self

Products of eigen() with self covariance matrices that are used as explanatory variables for the phenotype.

eigenK_nei

Products of eigen() with neighbor covariance matrices that are used as explanatory variables for the phenotype.

b_ratio

Ratio for contributions of eigenK_self and eigenK_nei to the phenotype.

pveB

Proportion of variance explained by genetic effects attributable to the fixed effects (i.e., b_.. vector).

pve

Proportion of variance explained by all genetic effects (i.e., b_.. and eigenK_..)

Author

Eiji Yamamoto, and Yasuhiro Sato